@@ -18,9 +18,9 @@ LANG=C rpm --checksig kernel-2.6.18-398.1.AXS3.src.rpm | grep -F ': (sha1) dsa s
 rpm -ivh kernel-2.6.18-398.1.AXS3.src.rpm || die "Can't install source package."
 
 cd /usr/src/asianux/SOURCES/ || die "Can't chdir to /usr/src/asianux/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.4-20150721.tar.gz ]
+if [ ! -r ccs-patch-1.8.4-20150928.tar.gz ]
 then
-    wget -O ccs-patch-1.8.4-20150721.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150721.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.4-20150928.tar.gz 'http://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150928.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -61,7 +61,7 @@ patch << "EOF" || die "Can't patch spec file."
  # end of Asianux patches
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.4-20150721.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.4-20150928.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.18-asianux-3.diff
 +
  cp %{SOURCE10} Documentation/
