@@ -75,9 +75,9 @@ LANG=C rpm --checksig kernel-default-3.7.10-1.45.1.nosrc.rpm | grep -F ': rsa sh
 rpm -ivh kernel-default-3.7.10-1.45.1.nosrc.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.4-20150721.tar.gz ]
+if [ ! -r ccs-patch-1.8.4-20150928.tar.gz ]
 then
-    wget -O ccs-patch-1.8.4-20150721.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150721.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.4-20150928.tar.gz 'http://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150928.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -105,7 +105,7 @@ patch << "EOF" || die "Can't patch spec file."
  	%_sourcedir/series.conf .. $SYMBOLS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.4-20150721.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.4-20150928.tar.gz
 +patch -sp1 < patches/ccs-patch-3.7-suse-12.3.diff
 +cat config.ccs >> ../config/%cpu_arch_flavor
 +
