@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is kernel build script for ubuntu 14.04's 3.13 kernel.
+# This is kernel build script for ubuntu 12.10's 3.5 kernel.
 #
 
 update_maintainer () {
@@ -29,23 +29,23 @@ apt-get -y install wget
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.4-20150721.tar.gz ]
+if [ ! -r ccs-patch-1.8.4-20150928.tar.gz ]
 then
-    wget -O ccs-patch-1.8.4-20150721.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150721.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.4-20150928.tar.gz 'http://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.4-20150928.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
 cd /usr/src/ || die "Can't chdir to /usr/src/ ."
 apt-get -y install fakeroot build-essential || die "Can't install packages."
 apt-get build-dep linux || die "Can't install packages."
-apt-get source linux-source-3.13.0 || die "Can't install kernel source."
-for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-3.13.0/debian/control`; do apt-get -y install $i; done
+apt-get source linux-source-3.5.0 || die "Can't install kernel source."
+for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-3.5.0/debian/control`; do apt-get -y install $i; done
 
 # Apply patches and create kernel config.
-cd linux-3.13.0/ || die "Can't chdir to linux-3.13.0/ ."
+cd linux-3.5.0/ || die "Can't chdir to linux-3.5.0/ ."
 update_maintainer
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.4-20150721.tar.gz || die "Can't extract patch."
-patch -p1 < patches/ccs-patch-3.13-ubuntu-14.04.diff || die "Can't apply patch."
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.4-20150928.tar.gz || die "Can't extract patch."
+patch -p1 < patches/ccs-patch-3.5-ubuntu-12.10.diff || die "Can't apply patch."
 rm -fR patches/ specs/ || die "Can't delete patch."
 for i in `find debian.master/ -type f -name '*'${ORIGINAL_FLAVOUR}'*'`; do cp -p $i `echo $i | sed -e 's/'${ORIGINAL_FLAVOUR}'/'${NEW_FLAVOUR}'/g'`; done
 for i in debian.master/config/*/config.common.*; do cat config.ccs >> $i; done
