@@ -51,6 +51,10 @@ static int __init ccs_setup(char *str)
 
 __setup("ccsecurity=", ccs_setup);
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 0, 0)
+#include "lsm2ccsecurity.c"
+#endif
+
 #ifndef CONFIG_CCSECURITY_OMIT_USERSPACE_LOADER
 
 /* Path to the policy loader. (default = CONFIG_CCSECURITY_POLICY_LOADER) */
@@ -314,6 +318,9 @@ const struct ccsecurity_exports ccsecurity_exports = {
 #ifndef CONFIG_CCSECURITY_OMIT_USERSPACE_LOADER
 	.load_policy = ccs_load_policy,
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0) && defined(CONFIG_SECURITY)
+	.add_hooks = ccs_add_hooks,
+#endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 2, 0)
 	.d_absolute_path = d_absolute_path,
 #elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36)
